@@ -119,7 +119,7 @@ class Subprocess:
                 st = None
 
         else:
-            path = self.config.options.get_path()
+            path = self.config.get_path()
             found = None
             st = None
             for dir in path:
